@@ -44,9 +44,9 @@ C<create>, C<insert>, C<list> and C<retrieve>.
 
 =cut
 
-use SOAP::Lite;
+require SOAP::Lite;
 use URI;
-use File::Spec;
+use File::Spec::Unix;
 use HTML::Entities;
 
 __PACKAGE__->mk_accessors( qw{ url user pass soap _login _server_details} );
@@ -66,21 +66,35 @@ __PACKAGE__->mk_accessors( qw{ url user pass soap _login _server_details} );
 sub connect {
     my ($class, $url,  $user, $pass, %opt) = @_;
 
+    $url =~ s{/$}{};
+
     my $uri_obj = URI->new($url, 'http');
 
-    my @path = File::Spec->splitdir($uri_obj->path);
+    my $uri_path = $uri_obj->path;
+
+    my @path = File::Spec::Unix->splitdir($uri_path);
+
+    shift (@path)
+	if (@path && !$path[0]);
 
     pop (@path)
 	if (@path && $path[-1] eq 'webservice.event');
 
-    $uri_obj->path(File::Spec->catdir(@path));
+    $uri_obj->path(File::Spec::Unix->catdir(@path));
     my $restful_url = $uri_obj->as_string;
 
-    $uri_obj->path(File::Spec->catdir(@path, 'webservice.event'));
+    $uri_obj->path(File::Spec::Unix->catdir(@path, 'webservice.event'));
     my $soap_url = $uri_obj->as_string;
 
+    my $debug = $opt{debug}||0;
+
     warn "connecting to ".$soap_url
-	if ($opt{debug});
+	if ($debug);
+
+    SOAP::Lite::import($debug >= 3
+		       ? (+trace => 'debug')
+		       : ()
+	);
 
     my $soap = SOAP::Lite->new(proxy => $soap_url );
 
